@@ -15,10 +15,11 @@
 
 import base64
 import os
+from unittest import mock
 
-from Crypto.Util import asn1
+from cryptography.hazmat.backends import default_backend
+from cryptography import x509
 import fixtures
-import mock
 from OpenSSL import crypto
 from oslo_config import fixture as oslo_fixture
 
@@ -49,7 +50,7 @@ class CaTestCase(BaseTestCase):
         ca = snakeoil_ca.SnakeoilCA(cert_path=None, key_path=None,
                                     key_size=512, subject_dn=subject_dn)
         subject = ca.cert.get_subject()
-        self.assertNotEqual(ca.key, None)
+        self.assertIsNotNone(ca.key)
         self.assertEqual("Test ST", subject.ST)
         self.assertEqual("Test L", subject.L)
         self.assertEqual("Test O", subject.O)
@@ -78,7 +79,7 @@ class CaTestCase(BaseTestCase):
         self.assertEqual(
             ca.chain,
             crypto.dump_certificate(crypto.FILETYPE_PEM, ca.cert))
-        self.assertNotEqual(None, ca.key)
+        self.assertIsNotNone(ca.key)
         self.assertEqual("Test ST", subject.ST)
         self.assertEqual("Test L", subject.L)
         self.assertEqual("Test O", subject.O)
@@ -148,13 +149,13 @@ class CertManagerTestCase(BaseTestCase):
                                          key_size=512, subject_dn=subject_dn)
 
     def verify_sig(self, encoded_cert):
-        der = asn1.DerSequence()
-        der.decode(encoded_cert)
-        der_sig = asn1.DerObject()
-        der_sig.decode(der[2])
-        sig = der_sig.payload
-        self.assertEqual(b'\x00', sig[:1])
-        crypto.verify(self.ca.cert, sig[1:], der[0], 'sha256')
+        cert = x509.load_der_x509_certificate(encoded_cert, default_backend())
+
+        crypto.verify(
+            self.ca.cert,
+            cert.signature,
+            cert.tbs_certificate_bytes,
+            'sha256')
 
     def test_gen_cert_no_file_storage(self):
         req = certificate_utils.get_valid_csr_object()
